/*
    Robot servo controller

    Gets data from the client and sends the data to a connected microcontroller

    (C) 2004 Jason Hunt

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    Contact: huntjas2@msu.edu

    Compile with -lwsock32

    On windows 2000 and XP you must install a real mode port assess driver.
    I use "userport"

    FILE: server.cpp
*/


#include <windows.h>
#include <stdio.h>

#include "server.h"
#include "display.h"
#include "network.h"
#include "control.h"
#include "window.h"
#include "key.h"

HWND main_win;              // keep track of the main window


int debug = 0;


/* ran when window is created */
void system_startup(HWND hwnd)
{
    clear_text_area();

    if(SetTimer(hwnd, ID_KEEP_ALIVE, 1000, NULL) == 0)
        add_line("Unable to set timer");

    startup_network(hwnd);  // start the network

    reset_controller(); // make sure motor controller is okay.
}
/* end of system_startup */


/* ran when window is closed */
void system_shutdown(void)
{
    shutdown_network();
    PostQuitMessage(0);       /* send a WM_QUIT to the message queue */
}
/* end of system_shutdown */


/* deal with the system timer */
void timer_message(WPARAM wParam)
{
    if (wParam == ID_KEEP_ALIVE && connected)
    {
        if (rec_data)
            rec_data = 0; // we have data, clear the flag
        else
            reset_network(); // no data, reset
    }
}
/* end of timer message */



/* the message handler */
LRESULT CALLBACK WinProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
{
    switch (message)                 
    {
        case WM_CREATE:   system_startup(hwnd);    break;

        case WM_NETEVENT: network_message(lParam); break;

        case WM_TIMER:    timer_message(wParam); break;

        case WM_DESTROY:  system_shutdown(); break;

        case WM_KEYDOWN:  process_key_down(wParam); break;

        case WM_KEYUP:    process_key_up(wParam); break;

        case WM_PAINT:    display_text_area(); break;

        default: return DefWindowProc (hwnd, message, wParam, lParam);
    }

    return(0);
}
/* end of winproc */



/* winmain */
int WINAPI WinMain(HINSTANCE hinstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
    // make the main window
    if (setup_window(hinstance, nCmdShow)) return(1);

    MSG messages;   

    while (GetMessage (&messages, NULL, 0, 0))
    {
        TranslateMessage(&messages);
        DispatchMessage(&messages);
    }

    return(messages.wParam);
}
/* end of winmain */



